@@ -852,7 +852,7 @@ int main(int argc, char *argv[])
 
 	if ( !debug ) {
 		if (daemon(1,0) == -1) {
-			glite_common_log(LOG_CATEGORY_CONTROL, LOG_PRIORITY_FATAL, "deamon()");
+			glite_common_log(LOG_CATEGORY_CONTROL, LOG_PRIORITY_FATAL, "daemon()");
 			exit(1);
 		}
 #ifdef LB_PERF
@@ -1130,7 +1130,11 @@ int bk_handle_connection(int conn, struct timeval *timeout, void *data)
 			ctx->id_mapping.rules[i].a = strdup(id_mapping.rules[i].a);
 			ctx->id_mapping.rules[i].b = strdup(id_mapping.rules[i].b);
 		}
+		//ctx->id_mapping.mapfile = strdup(id_mapping.mapfile);
+		ctx->mapfile = strdup(gridmap);	//TODO: Switch back into id_mapping on next major release
 	}
+	else //ctx->id_mapping.mapfile = NULL;
+		ctx->mapfile = NULL;	//TODO: Switch back into id_mapping on next major release
 
 	gettimeofday(&conn_start, 0);
 
