@@ -190,6 +190,124 @@ int collate_history(edg_wll_Context ctx, edg_wll_JobStat *stat, edg_wll_Event* e
 //       return edg_wll_Error(ctx, NULL, NULL);
 //}
 
+int edg_wll_AreThereZombies(edg_wll_Context ctx, const edg_wll_QueryRec **conditions) {
+	char *out[2], *uniq, *ss;
+	char **prefix, **prefix_id, **suffix, **suffix_id;
+	int s,lendiff,i=0,j,k,l;
+	char	*zquery = NULL,
+		*zomb_where = NULL,
+		*zomb_where_temp = NULL,
+		*dbjob;
+	glite_lbu_Statement sh;
+
+
+	//Load up prefixes and suffixes from the DB
+	trio_asprintf(&zquery,"SELECT prefix_id,prefix FROM zombie_prefixes");
+	glite_common_log_msg(LOG_CATEGORY_LB_SERVER_DB, LOG_PRIORITY_DEBUG, zquery);
+	if (!(j = edg_wll_ExecSQL(ctx,zquery,&sh))) {
+		glite_common_log_msg(LOG_CATEGORY_LB_SERVER, LOG_PRIORITY_ERROR, "zombie_prefixes table is empty");
+		free(zquery);
+		return(0);
+	}
+	i = 0;
+	prefix=(char**)calloc(sizeof(char*), j+1);
+	prefix_id=(char**)calloc(sizeof(char*), j+1);
+	while(edg_wll_FetchRow(ctx, sh, sizeof(out)/sizeof(out[0]), NULL, out)) {
+		asprintf(&(prefix[i]),"https://%s", out[1]);
+		prefix_id[i++]=strdup(out[0]);
+	}
+
+	glite_lbu_FreeStmt(&sh);
+	free(zquery);
+
+	trio_asprintf(&zquery,"SELECT suffix_id,suffix FROM zombie_suffixes");
+	glite_common_log_msg(LOG_CATEGORY_LB_SERVER_DB, LOG_PRIORITY_DEBUG, zquery);
+	if (!(j = edg_wll_ExecSQL(ctx,zquery,&sh))) {
+		glite_common_log_msg(LOG_CATEGORY_LB_SERVER, LOG_PRIORITY_ERROR, "zombie_suffixes table is empty");
+		free(zquery);
+		return(0);
+	}
+	i = 0;
+	suffix=(char**)calloc(sizeof(char*), j+1);
+	suffix_id=(char**)calloc(sizeof(char*), j+1);
+	while(edg_wll_FetchRow(ctx, sh, sizeof(out)/sizeof(out[0]), NULL, out)) {
+		suffix[i]=strdup(out[1]);
+		suffix_id[i++]=strdup(out[0]);
+	}
+
+	glite_lbu_FreeStmt(&sh);
+	free(zquery);
+
+
+	i = 0;
+	s = 0;
+	while(conditions[i]) {
+		j = 0;
+		while(conditions[i][j].attr) {
+
+			if(conditions[i][j].attr == EDG_WLL_QUERY_ATTR_JOBID) {
+				dbjob = glite_jobid_unparse(conditions[i][j].value.j);
+				for (k = 0; prefix[k]; k++) {
+					if (!strncmp(prefix[k], dbjob, strlen(prefix[k]))) {
+						uniq = dbjob+strlen(prefix[k]);
+						for (l = 0; suffix[l]; l++) {
+							lendiff=strlen(uniq)-strlen(suffix[l]);
+							if ((lendiff>0) && (!strcmp(uniq+lendiff,suffix[l]))) {
+								ss=strdup(uniq);
+								ss[lendiff]=0;
+								asprintf(&zomb_where_temp,"%s%s((prefix_id=%s) AND (jobid='%s') AND (suffix_id=%s))",
+									zomb_where ? zomb_where : "",
+									s ? " OR " : "",
+									prefix_id[k],
+									ss,
+									suffix_id[l]);
+								free(ss);
+								free(zomb_where);
+								zomb_where=zomb_where_temp;
+								s++;
+							}
+						}
+					}
+				}
+			}
+			j++;
+		}
+		i++;
+	}
+	for (i=0; prefix[i]; i++) { free(prefix[i]); free(prefix_id[i]); } free(prefix); free(prefix_id);
+	for (i=0; suffix[i]; i++) { free(suffix[i]); free(suffix_id[i]); } free(suffix); free(suffix_id);
+	trio_asprintf(&zquery,"SELECT * FROM zombie_jobs WHERE %s", zomb_where);
+
+	glite_common_log_msg(LOG_CATEGORY_LB_SERVER_DB,
+		LOG_PRIORITY_DEBUG, zquery);
+	j = edg_wll_ExecSQL(ctx,zquery,&sh);
+
+	glite_lbu_FreeStmt(&sh);
+	free (zquery);
+	
+	return(j);
+}
+
+int edg_wll_IsJobZombie(edg_wll_Context ctx, glite_jobid_const_t job) {
+	int ret;
+        edg_wll_QueryRec        zqr[2];
+        edg_wll_QueryRec        **zqra;
+
+        zqr[0].attr = EDG_WLL_QUERY_ATTR_JOBID;
+        zqr[0].op = EDG_WLL_QUERY_OP_EQUAL;
+        zqr[0].value.j = (glite_jobid_t)job;
+        zqr[1].attr = EDG_WLL_QUERY_ATTR_UNDEF;
+
+        zqra = (edg_wll_QueryRec **) malloc (2 * sizeof(edg_wll_QueryRec **));
+        zqra[0] = zqr;
+        zqra[1] = NULL;
+
+	ret = edg_wll_AreThereZombies(ctx, (const edg_wll_QueryRec**) zqra);
+	free(zqra);
+
+	return(ret);
+}
+
 int edg_wll_JobStatusServer(
 	edg_wll_Context	ctx,
 	glite_jobid_const_t		job,
@@ -228,8 +346,10 @@ int edg_wll_JobStatusServer(
 		whole_cycle = 0;
 
 		if (edg_wll_Transaction(ctx)) goto rollback;
-		if (edg_wll_LockJobRowInShareMode(ctx, md5_jobid)) goto rollback;
-
+		if (edg_wll_LockJobRowInShareMode(ctx, md5_jobid)) {
+			if (edg_wll_IsJobZombie(ctx, job)) edg_wll_SetError(ctx, EIDRM, "matching job already purged");
+			goto rollback; 
+		}
 
 		if (!edg_wll_LoadIntState(ctx, job, DONT_LOCK, -1 /*all events*/, &ijsp)) {
 			memcpy(stat, intJobStat_to_JobStat(ijsp), sizeof(*stat));
@@ -580,7 +700,8 @@ int edg_wll_intJobStatus(
 	jqra[1] = NULL;
 
 	if (edg_wll_QueryEventsServer(ctx,1, (const edg_wll_QueryRec **)jqra, NULL, &events)) {
-		if (edg_wll_Error(ctx, NULL, NULL) == ENOENT) {
+		if ((edg_wll_Error(ctx, NULL, NULL) == ENOENT) ||
+		    (edg_wll_Error(ctx, NULL, NULL) == EIDRM)) {
 			if (edg_wll_RestoreSubjobState(ctx, job, intstat)) {
 				if (edg_wll_Error(ctx, NULL, NULL) != ENOENT) {
 					destroy_intJobStat(intstat);
