@@ -127,9 +127,8 @@ int relationship_cmp (const void *a, const void *b) {
 }
 
 int edg_wll_ConfigurationToHTML(edg_wll_Context ctx, int admin, char **message, int text){
-        char *a = NULL, *b, *header, *out, *out_tmp;
+        char *a = NULL, *header, *out, *out_tmp;
         int i = 0;
-        b = strdup("");
 
         header = get_html_header(ctx, text);
         if (!text) asprintf(&out, "<HTML>\n<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 3.2 Final//EN\">\n<TITLE>Server Configuration</TITLE>\n<HEAD>%s\n</HEAD>\n<BODY>\n"
@@ -222,6 +221,8 @@ int edg_wll_ConfigurationToHTML(edg_wll_Context ctx, int admin, char **message,
 		add_row(&out, "purge_prefix", "Purge file prefix", ctx->purgeStorage, NULL, text);
 		add_row(&out, "html_header", "HTML Header file", ctx->html_header_file, NULL, text);
 
+		//add_row(&out, "id_mapping_file", "ID Mapping File", ctx->id_mapping.mapfile, NULL, text);
+		add_row(&out, "id_mapping_file", "ID Mapping File", ctx->mapfile, NULL, text); //TODO: Switch back into id_mapping on next major release
 		a = NULL;
 		for (i = 0; i < ctx->id_mapping.num; i++ ) {
 			asprintf(&out_tmp, "%s%s\"%s\"%s\"%s\"%s%s",
