@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.server/src/server_state.c,v 1.10 2011/10/25 13:32:14 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -40,7 +40,7 @@ int edg_wll_GetServerState(edg_wll_Context ctx,const char *name,char **val)
 	switch (edg_wll_ExecSQL(ctx,stmt,&q)) {
 		case 0: edg_wll_SetError(ctx,ENOENT,name); break;
 		case -1: break;
-		default: edg_wll_FetchRow(ctx,q,sizeof(val)/sizeof(val[0]),NULL,val); break;
+		default: edg_wll_FetchRow(ctx,q,1,NULL,val); break;
 	}
 
 	glite_lbu_FreeStmt(&q);
